@@ -3,7 +3,7 @@ package FlyBy;
 use strict;
 use warnings;
 use 5.010;
-our $VERSION = '0.092';
+our $VERSION = '0.093';
 
 use Moo;
 
@@ -125,7 +125,7 @@ sub query {
 
         # Now convert the supplied hashref to an array reference we can use.
         my %qhash = %$query_clauses;
-        $query_clauses = [map { [$_ => $qhash{$_}] } keys %qhash];
+        $query_clauses = [map { [$_ => $qhash{$_}] } grep { defined $qhash{$_} } keys %qhash];
     }
 
     my $match_set = $self->_full_set;
@@ -169,7 +169,9 @@ sub query {
             }
         }
     } else {
-        @results = map { $records->[$_] } @indices;
+        @results = map {
+            { %{$records->[$_]} }
+        } @indices;
     }
 
     return @results;
